==> passenger-5.0.30-2-aarch64.pkg.tar.xz: usr/lib/passenger/src/agent/Core/Controller/Implementation.cpp <==
/*
 *  Phusion Passenger - https://www.phusionpassenger.com/
 *  Copyright (c) 2015 Phusion Holding B.V.
 *
 *  "Passenger", "Phusion Passenger" and "Union Station" are registered
 *  trademarks of Phusion Holding B.V.
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 *  THE SOFTWARE.
 */

#include <Core/Controller.h>
#include <Core/Controller/InitRequest.cpp>
#include <Core/Controller/BufferBody.cpp>
#include <Core/Controller/CheckoutSession.cpp>
#include <Core/Controller/SendRequest.cpp>
#include <Core/Controller/ForwardResponse.cpp>
#include <Core/Controller/Hooks.cpp>
#include <Core/Controller/InitializationAndShutdown.cpp>
#include <Core/Controller/InternalUtils.cpp>
#include <Core/Controller/Miscellaneous.cpp>
#include <Core/Controller/StateInspectionAndConfiguration.cpp>

==> passenger-5.1.7-1-aarch64.pkg.tar.xz: usr/lib/passenger/src/agent/Core/Controller/Implementation.cpp <==
/*
 *  Phusion Passenger - https://www.phusionpassenger.com/
 *  Copyright (c) 2015-2017 Phusion Holding B.V.
 *
 *  "Passenger", "Phusion Passenger" and "Union Station" are registered
 *  trademarks of Phusion Holding B.V.
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 *  THE SOFTWARE.
 */

#include <Core/Controller.h>
#include <Core/Controller/InitRequest.cpp>
#include <Core/Controller/BufferBody.cpp>
#include <Core/Controller/CheckoutSession.cpp>
#include <Core/Controller/SendRequest.cpp>
#include <Core/Controller/ForwardResponse.cpp>
#include <Core/Controller/Hooks.cpp>
#include <Core/Controller/InitializationAndShutdown.cpp>
#include <Core/Controller/InternalUtils.cpp>
#include <Core/Controller/Miscellaneous.cpp>
#include <Core/Controller/StateInspection.cpp>
